[Bf-blender-cvs] [39daf28] master: Don't use with_resol suffix for functions which doesn't get resolution

Sergey Sharybin noreply at git.blender.org
Fri Dec 20 11:01:07 CET 2013


Commit: 39daf283ae260b6cd8b85e4b269959c421010268
Author: Sergey Sharybin
Date:   Fri Dec 20 16:00:05 2013 +0600
http://developer.blender.org/rB39daf283ae260b6cd8b85e4b269959c421010268

Don't use with_resol suffix for functions which doesn't get resolution

===================================================================

M	source/blender/blenkernel/BKE_mask.h
M	source/blender/blenkernel/intern/mask_evaluate.c
M	source/blender/blenkernel/intern/mask_rasterize.c
M	source/blender/editors/mask/mask_add.c
M	source/blender/editors/mask/mask_draw.c

===================================================================

diff --git a/source/blender/blenkernel/BKE_mask.h b/source/blender/blenkernel/BKE_mask.h
index 8d2233f..125a435 100644
--- a/source/blender/blenkernel/BKE_mask.h
+++ b/source/blender/blenkernel/BKE_mask.h
@@ -189,23 +189,23 @@ unsigned int BKE_mask_spline_resolution(struct MaskSpline *spline, int width, in
 unsigned int BKE_mask_spline_feather_resolution(struct MaskSpline *spline, int width, int height);
 int          BKE_mask_spline_differentiate_calc_total(const struct MaskSpline *spline, const unsigned int resol);
 
-float (*BKE_mask_spline_differentiate_with_resolution_ex(struct MaskSpline *spline, unsigned int *tot_diff_point,
-                                                         const unsigned int resol))[2];
+float (*BKE_mask_spline_differentiate_with_resolution(struct MaskSpline *spline, unsigned int *tot_diff_point,
+                                                      const unsigned int resol))[2];
 void    BKE_mask_spline_feather_collapse_inner_loops(struct MaskSpline *spline, float (*feather_points)[2], const unsigned int tot_feather_point);
-float (*BKE_mask_spline_differentiate_with_resolution(struct MaskSpline *spline, int width, int height, unsigned int *tot_diff_point))[2];
-float (*BKE_mask_spline_feather_differentiated_points_with_resolution_ex(struct MaskSpline *spline, unsigned int *tot_feather_point,
-                                                                         const unsigned int resol, const int do_feather_isect))[2];
+float (*BKE_mask_spline_differentiate(struct MaskSpline *spline, int width, int height, unsigned int *tot_diff_point))[2];
+float (*BKE_mask_spline_feather_differentiated_points_with_resolution(struct MaskSpline *spline, unsigned int *tot_feather_point,
+                                                                      const unsigned int resol, const int do_feather_isect))[2];
 
 /* *** mask point functions which involve evaluation *** */
 float (*BKE_mask_spline_feather_points(struct MaskSpline *spline, int *tot_feather_point))[2];
 
-float *BKE_mask_point_segment_diff_with_resolution(struct MaskSpline *spline, struct MaskSplinePoint *point,
-                                                   int width, int height,
-                                                   unsigned int *tot_diff_point);
+float *BKE_mask_point_segment_diff(struct MaskSpline *spline, struct MaskSplinePoint *point,
+                                   int width, int height,
+                                   unsigned int *tot_diff_point);
 
-float *BKE_mask_point_segment_feather_diff_with_resolution(struct MaskSpline *spline, struct MaskSplinePoint *point,
-                                                           int width, int height,
-                                                           unsigned int *tot_feather_point);
+float *BKE_mask_point_segment_feather_diff(struct MaskSpline *spline, struct MaskSplinePoint *point,
+                                           int width, int height,
+                                           unsigned int *tot_feather_point);
 
 /* mask_rasterize.c */
 struct MaskRasterHandle;
diff --git a/source/blender/blenkernel/intern/mask_evaluate.c b/source/blender/blenkernel/intern/mask_evaluate.c
index 2a4ba5a..f63d027 100644
--- a/source/blender/blenkernel/intern/mask_evaluate.c
+++ b/source/blender/blenkernel/intern/mask_evaluate.c
@@ -154,10 +154,10 @@ int BKE_mask_spline_differentiate_calc_total(const MaskSpline *spline, const uns
 	}
 }
 
-float (*BKE_mask_spline_differentiate_with_resolution_ex(MaskSpline *spline,
-                                                         unsigned int *tot_diff_point,
-                                                         const unsigned int resol
-                                                         ))[2]
+float (*BKE_mask_spline_differentiate_with_resolution(MaskSpline *spline,
+                                                      unsigned int *tot_diff_point,
+                                                      const unsigned int resol
+                                                      ))[2]
 {
 	MaskSplinePoint *points_array = BKE_mask_spline_point_array(spline);
 
@@ -213,13 +213,13 @@ float (*BKE_mask_spline_differentiate_with_resolution_ex(MaskSpline *spline,
 	return diff_points;
 }
 
-float (*BKE_mask_spline_differentiate_with_resolution(MaskSpline *spline, int width, int height,
-                                                      unsigned int *tot_diff_point
-                                                      ))[2]
+float (*BKE_mask_spline_differentiate(MaskSpline *spline, int width, int height,
+                                      unsigned int *tot_diff_point
+                                      ))[2]
 {
 	int unsigned resol = BKE_mask_spline_resolution(spline, width, height);
 
-	return BKE_mask_spline_differentiate_with_resolution_ex(spline, tot_diff_point, resol);
+	return BKE_mask_spline_differentiate_with_resolution(spline, tot_diff_point, resol);
 }
 
 /* ** feather points self-intersection collapse routine ** */
@@ -501,12 +501,12 @@ void BKE_mask_spline_feather_collapse_inner_loops(MaskSpline *spline, float (*fe
 #undef BUCKET_INDEX
 }
 
-/** only called from #BKE_mask_spline_feather_differentiated_points_with_resolution_ex() ! */
-static float (*mask_spline_feather_differentiated_points_with_resolution_ex__even(MaskSpline *spline,
-                                                                                  unsigned int *tot_feather_point,
-                                                                                  const unsigned int resol,
-                                                                                  const int do_feather_isect
-                                                                                  ))[2]
+/** only called from #BKE_mask_spline_feather_differentiated_points_with_resolution() ! */
+static float (*mask_spline_feather_differentiated_points_with_resolution__even(MaskSpline *spline,
+                                                                               unsigned int *tot_feather_point,
+                                                                               const unsigned int resol,
+                                                                               const int do_feather_isect
+                                                                               ))[2]
 {
 	MaskSplinePoint *points_array = BKE_mask_spline_point_array(spline);
 	MaskSplinePoint *point_curr, *point_prev;
@@ -574,12 +574,12 @@ static float (*mask_spline_feather_differentiated_points_with_resolution_ex__eve
 	return feather;
 }
 
-/** only called from #BKE_mask_spline_feather_differentiated_points_with_resolution_ex() ! */
-static float (*mask_spline_feather_differentiated_points_with_resolution_ex__double(MaskSpline *spline,
-                                                                                    unsigned int *tot_feather_point,
-                                                                                    const unsigned int resol,
-                                                                                    const int do_feather_isect
-                                                                                    ))[2]
+/** only called from #BKE_mask_spline_feather_differentiated_points_with_resolution() ! */
+static float (*mask_spline_feather_differentiated_points_with_resolution__double(MaskSpline *spline,
+                                                                                 unsigned int *tot_feather_point,
+                                                                                 const unsigned int resol,
+                                                                                 const int do_feather_isect
+                                                                                 ))[2]
 {
 	MaskSplinePoint *points_array = BKE_mask_spline_point_array(spline);
 
@@ -709,22 +709,22 @@ static float (*mask_spline_feather_differentiated_points_with_resolution_ex__dou
 }
 
 /**
- * values align with #BKE_mask_spline_differentiate_with_resolution_ex
+ * values align with #BKE_mask_spline_differentiate_with_resolution
  * when \a resol arguments match.
  */
-float (*BKE_mask_spline_feather_differentiated_points_with_resolution_ex(MaskSpline *spline,
-                                                                         unsigned int *tot_feather_point,
-                                                                         const unsigned int resol,
-                                                                         const int do_feather_isect
-                                                                         ))[2]
+float (*BKE_mask_spline_feather_differentiated_points_with_resolution(MaskSpline *spline,
+                                                                      unsigned int *tot_feather_point,
+                                                                      const unsigned int resol,
+                                                                      const int do_feather_isect
+                                                                      ))[2]
 {
 	switch (spline->offset_mode) {
 		case MASK_SPLINE_OFFSET_EVEN:
-			return mask_spline_feather_differentiated_points_with_resolution_ex__even(spline, tot_feather_point, resol, do_feather_isect);
+			return mask_spline_feather_differentiated_points_with_resolution__even(spline, tot_feather_point, resol, do_feather_isect);
 			break;
 		case MASK_SPLINE_OFFSET_SMOOTH:
 		default:
-			return mask_spline_feather_differentiated_points_with_resolution_ex__double(spline, tot_feather_point, resol, do_feather_isect);
+			return mask_spline_feather_differentiated_points_with_resolution__double(spline, tot_feather_point, resol, do_feather_isect);
 			break;
 	}
 }
@@ -777,9 +777,9 @@ float (*BKE_mask_spline_feather_points(MaskSpline *spline, int *tot_feather_poin
 }
 
 /* *** mask point functions which involve evaluation *** */
-float *BKE_mask_point_segment_feather_diff_with_resolution(MaskSpline *spline, MaskSplinePoint *point,
-                                                           int width, int height,


@@ Diff output truncated at 10240 characters. @@




More information about the Bf-blender-cvs mailing list